@@ -1,11 +1,15 @@
 import { DataSourcePlugin } from '@grafana/data';
-import { SQLQuery, SqlQueryEditorLazy } from '@grafana/sql';
+import { initPluginTranslations } from '@grafana/i18n';
+import { SQLQuery, SqlQueryEditorLazy, loadResources as loadSQLResources } from '@grafana/sql';
 
 import { CheatSheet } from './CheatSheet';
 import { ConfigurationEditor } from './configuration/ConfigurationEditor';
 import { MssqlDatasource } from './datasource';
+import pluginJson from './plugin.json';
 import { MssqlOptions } from './types';
 
+initPluginTranslations(pluginJson.id, [loadSQLResources]);
+
 export const plugin = new DataSourcePlugin<MssqlDatasource, SQLQuery, MssqlOptions>(MssqlDatasource)
   .setQueryEditor(SqlQueryEditorLazy)
   .setQueryEditorHelp(CheatSheet)
